pub enum EcmaScriptTarget {
Es5,
Es2015,
Es2016,
Es2017,
Es2018,
Es2019,
Es2020,
Es2021,
Es2022,
Es2023,
Es2024,
EsNext,
}Expand description
Common ECMAScript language target labels.
Variants
Implementations
Sourceimpl EcmaScriptTarget
impl EcmaScriptTarget
Sourcepub const fn year(self) -> Option<EcmaScriptYear>
pub const fn year(self) -> Option<EcmaScriptYear>
Returns the annual edition year when the target has one.
Sourcepub const fn edition(self) -> Option<EcmaScriptEdition>
pub const fn edition(self) -> Option<EcmaScriptEdition>
Returns the edition number when the target maps to a stable edition.